From 4a734a427ee7785cdc7bebec779761fc0e9c4b7a Mon Sep 17 00:00:00 2001
From: Hans-Christoph Steiner <hans@eds.org>
Date: Tue, 18 Dec 2012 12:05:45 -0500
Subject: [PATCH 1/1] restore sys_close() as a function on all platforms to
 retain ABI compatibility

---
 src/m_pd.h   |    7 +++++--
 src/s_path.c |   16 ++++++++++------
 2 files changed, 15 insertions(+), 8 deletions(-)

diff --git a/src/m_pd.h b/src/m_pd.h
index cb81858..ac76936 100644
--- a/src/m_pd.h
+++ b/src/m_pd.h
@@ -539,15 +539,18 @@ EXTERN int (*sys_idlehook)(void);   /* hook to add idle time computation */
  * objectclasses as well so they work with Unicode filenames on Windows */
 #ifdef _WIN32
 EXTERN int sys_open(const char *path, int oflag, ...);
-EXTERN int sys_close(int fd);
 EXTERN FILE *sys_fopen(const char *filename, const char *mode);
 EXTERN int sys_fclose(FILE *stream);
 #else
 # define sys_open open
-# define sys_close close
 # define sys_fopen fopen
 # define sys_fclose fclose
 #endif
+/* Even though on all platforms but Win32, sys_close could be a macro
+ * to make an alias like above, it has been a part of this header for
+ * a long time, so converting it to a macro breaks backwards ABI
+ * compatibility.  Therefore we keep it as a function. */
+EXTERN int sys_close(int fd);
 
 
 /* ------------  threading ------------------- */ 
diff --git a/src/s_path.c b/src/s_path.c
index 9a63bda..25bedc3 100644
--- a/src/s_path.c
+++ b/src/s_path.c
@@ -426,20 +426,24 @@ FILE *sys_fopen(const char *filename, const char *mode)
     return (_wfopen(ucs2buf, ucs2mode));
 }
 
+int sys_fclose(FILE *stream)
+{
+    return fclose(stream);
+}
+#endif /* _WIN32 */
+
    /* close a previously opened file
    this is needed on platforms where you cannot open/close resources
    across dll-boundaries */
 int sys_close(int fd)
 {
+#ifdef _WIN32
     return _close(fd);
+#else
+    return close(fd);
+#endif
 }
 
-int sys_fclose(FILE *stream)
-{
-    return fclose(stream);
-}
-#endif /* _WIN32 */
-
 
     /* Open a help file using the help search path.  We expect the ".pd"
     suffix here, even though we have to tear it back off for one of the
-- 
1.7.10.1

